@@ -35,6 +35,8 @@ typedef ECalBackendFactoryClass ECalBackendFileJournalFactoryClass;
 typedef ECalBackendFactory ECalBackendFileTodosFactory;
 typedef ECalBackendFactoryClass ECalBackendFileTodosFactoryClass;
 
+static EModule *e_module;
+
 /* Module Entry Points */
 void e_module_load (GTypeModule *type_module);
 void e_module_unload (GTypeModule *type_module);
@@ -62,6 +64,12 @@ G_DEFINE_DYNAMIC_TYPE (
 static void
 e_cal_backend_file_events_factory_class_init (ECalBackendFactoryClass *class)
 {
+	EBackendFactoryClass *backend_factory_class;
+
+	backend_factory_class = E_BACKEND_FACTORY_CLASS (class);
+	backend_factory_class->e_module = e_module;
+	backend_factory_class->share_subprocess = TRUE;
+
 	class->factory_name = FACTORY_NAME;
 	class->component_kind = ICAL_VEVENT_COMPONENT;
 	class->backend_type = E_TYPE_CAL_BACKEND_FILE_EVENTS;
@@ -80,6 +88,12 @@ e_cal_backend_file_events_factory_init (ECalBackendFactory *factory)
 static void
 e_cal_backend_file_journal_factory_class_init (ECalBackendFactoryClass *class)
 {
+	EBackendFactoryClass *backend_factory_class;
+
+	backend_factory_class = E_BACKEND_FACTORY_CLASS (class);
+	backend_factory_class->e_module = e_module;
+	backend_factory_class->share_subprocess = TRUE;
+
 	class->factory_name = FACTORY_NAME;
 	class->component_kind = ICAL_VJOURNAL_COMPONENT;
 	class->backend_type = E_TYPE_CAL_BACKEND_FILE_JOURNAL;
@@ -98,6 +112,12 @@ e_cal_backend_file_journal_factory_init (ECalBackendFactory *factory)
 static void
 e_cal_backend_file_todos_factory_class_init (ECalBackendFactoryClass *class)
 {
+	EBackendFactoryClass *backend_factory_class;
+
+	backend_factory_class = E_BACKEND_FACTORY_CLASS (class);
+	backend_factory_class->e_module = e_module;
+	backend_factory_class->share_subprocess = TRUE;
+
 	class->factory_name = FACTORY_NAME;
 	class->component_kind = ICAL_VTODO_COMPONENT;
 	class->backend_type = E_TYPE_CAL_BACKEND_FILE_TODOS;
@@ -116,6 +136,8 @@ e_cal_backend_file_todos_factory_init (ECalBackendFactory *factory)
 G_MODULE_EXPORT void
 e_module_load (GTypeModule *type_module)
 {
+	e_module = E_MODULE (type_module);
+
 	e_source_local_type_register (type_module);
 	e_cal_backend_file_events_factory_register_type (type_module);
 	e_cal_backend_file_journal_factory_register_type (type_module);
@@ -125,5 +147,6 @@ e_module_load (GTypeModule *type_module)
 G_MODULE_EXPORT void
 e_module_unload (GTypeModule *type_module)
 {
+	e_module = NULL;
 }
 
