@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
- *
- * Authors: Michael Zucchi <notzed@ximian.com>
- *	    Jeffrey Stedfast <fejj@ximian.com>
- *	    Chris Toshok <toshok@ximian.com>
- *
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *for more details.
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Michael Zucchi <notzed@ximian.com>
+ *	    Jeffrey Stedfast <fejj@ximian.com>
+ *	    Chris Toshok <toshok@ximian.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,8 +27,6 @@
 #include <stdio.h>
 
 #include <glib/gi18n-lib.h>
-#include <unicode/uidna.h>
-#include <unicode/ustring.h>
 
 #include "camel-msgport.h"
 #include "camel-net-utils.h"
@@ -695,8 +693,6 @@ camel_getaddrinfo (const gchar *name,
 #ifndef ENABLE_IPv6
 	struct addrinfo myhints;
 #endif
-	gchar *ascii_name;
-
 	g_return_val_if_fail (name != NULL, NULL);
 
 	if (g_cancellable_set_error_if_cancelled (cancellable, error))
@@ -716,10 +712,8 @@ camel_getaddrinfo (const gchar *name,
 	hints = &myhints;
 #endif
 
-	ascii_name = camel_host_idna_to_ascii (name);
-
 	msg = g_malloc0 (sizeof (*msg));
-	msg->name = ascii_name;
+	msg->name = name;
 	msg->service = service;
 	msg->hints = hints;
 	msg->res = &res;
@@ -745,7 +739,6 @@ camel_getaddrinfo (const gchar *name,
 		res = NULL;
 
 	cs_freeinfo (msg);
-	g_free (ascii_name);
 
 	camel_operation_pop_message (cancellable);
 
@@ -774,75 +767,3 @@ camel_freeaddrinfo (struct addrinfo *host)
 #endif
 }
 
-/**
- * camel_host_idna_to_ascii:
- * @host: Host name, with or without non-ascii letters in utf8
- *
- * Converts IDN (Internationalized Domain Name) into ASCII representation.
- * If there's a failure or the @host has only ASCII letters, then a copy
- * of @host is returned.
- *
- * Returns: Newly allocated string with only ASCII letters describing the @host.
- *   Free it with g_free() when done with it.
- *
- * Since: 3.12.6
- **/
-gchar *
-camel_host_idna_to_ascii (const gchar *host)
-{
-	UErrorCode uerror = U_ZERO_ERROR;
-	int32_t uhost_len = 0;
-	const gchar *ptr;
-	gchar *ascii = NULL;
-
-	g_return_val_if_fail (host != NULL, NULL);
-
-	ptr = host;
-	while (*ptr > 0)
-		ptr++;
-
-	if (!*ptr) {
-		/* Did read whole buffer, it should be ASCII string already */
-		return g_strdup (host);
-	}
-
-	u_strFromUTF8 (NULL, 0, &uhost_len, host, -1, &uerror);
-	if (uhost_len > 0) {
-		UChar *uhost = g_new0 (UChar, uhost_len + 2);
-
-		uerror = U_ZERO_ERROR;
-		u_strFromUTF8 (uhost, uhost_len + 1, &uhost_len, host, -1, &uerror);
-		if (uerror == U_ZERO_ERROR && uhost_len > 0) {
-			int32_t buffer_len = uhost_len * 6 + 6, nconverted;
-			UChar *buffer = g_new0 (UChar, buffer_len);
-
-			nconverted = uidna_IDNToASCII (uhost, uhost_len, buffer, buffer_len, UIDNA_ALLOW_UNASSIGNED, 0, &uerror);
-			if (uerror == U_ZERO_ERROR && nconverted > 0) {
-				int32_t ascii_len = 0;
-
-				u_strToUTF8 (NULL, 0, &ascii_len, buffer, nconverted, &uerror);
-				if (ascii_len > 0) {
-					uerror = U_ZERO_ERROR;
-					ascii = g_new0 (gchar, ascii_len + 2);
-
-					u_strToUTF8 (ascii, ascii_len + 1, &ascii_len, buffer, nconverted, &uerror);
-					if (uerror == U_ZERO_ERROR && ascii_len > 0) {
-						ascii[ascii_len] = '\0';
-					} else {
-						g_free (ascii);
-						ascii = NULL;
-					}
-				}
-			}
-
-			g_free (buffer);
-		}
-
-		g_free (uhost);
-	}
-
-	if (!ascii)
-		ascii = g_strdup (host);
-
-	return ascii;
-}
