@@ -76,6 +76,12 @@ extern gss_OID gss_nt_service_name;
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), CAMEL_TYPE_SASL_GSSAPI, CamelSaslGssapiPrivate))
 
+static const char spnego_OID[] = "\x2b\x06\x01\x05\x05\x02";
+static const gss_OID_desc gss_mech_spnego = {
+       6,
+       &spnego_OID
+};
+
 #ifndef GSS_C_OID_KRBV5_DES
 #define GSS_C_OID_KRBV5_DES GSS_C_NO_OID
 #endif
@@ -113,6 +119,7 @@ struct _CamelSaslGssapiPrivate {
 	gss_name_t target;
 	gchar *override_host;
 	gchar *override_user;
+	gss_OID mech, used_mech;
 };
 
 #endif /* HAVE_KRB5 */
@@ -122,8 +129,49 @@ G_DEFINE_TYPE (CamelSaslGssapi, camel_sasl_gssapi, CAMEL_TYPE_SASL)
 #ifdef HAVE_KRB5
 
 static void
-gssapi_set_exception (OM_uint32 major,
-                      OM_uint32 minor,
+gssapi_set_mechanism_exception (gss_OID mech, OM_uint32 minor, GError **error)
+{
+	OM_uint32 tmajor, tminor, message_status = 0;
+	char *message = NULL;
+
+	do {
+		char *message_part;
+		char *new_message;
+		gss_buffer_desc status_string;
+
+		tmajor = gss_display_status (&tminor, minor, GSS_C_MECH_CODE,
+					     mech, &message_status,
+					     &status_string);
+
+		if (tmajor != GSS_S_COMPLETE) {
+			message_part = g_strdup_printf (
+				_("(Unknown GSSAPI mechanism code: %x)"),
+				minor);
+			message_status = 0;
+		} else {
+			message_part = g_strdup (status_string.value);
+			gss_release_buffer (&tminor, &status_string);
+		}
+		if (message) {
+			new_message = g_strconcat (message, message_part, NULL);
+			free (message_part);
+		} else {
+			new_message = message_part;
+		}
+		g_free (message);
+		message = new_message;
+	} while (message_status != 0);
+
+	g_set_error (
+		error, CAMEL_SERVICE_ERROR,
+		CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE,
+		"%s", message);
+
+	g_free (message);
+}
+
+static void
+gssapi_set_exception (gss_OID mech, OM_uint32 major, OM_uint32 minor,
                       GError **error)
 {
 	const gchar *str;
@@ -168,7 +216,7 @@ gssapi_set_exception (OM_uint32 major,
 		str = _("The referenced credentials have expired.");
 		break;
 	case GSS_S_FAILURE:
-		str = error_message (minor);
+		return gssapi_set_mechanism_exception (mech, minor, error);
 		break;
 	default:
 		str = _("Bad authentication response from server.");
@@ -279,7 +327,6 @@ sasl_gssapi_challenge_sync (CamelSasl *sasl,
 	gss_buffer_t input_token;
 	gint conf_state;
 	gss_qop_t qop;
-	gss_OID mech;
 	gchar *str;
 	struct addrinfo *ai, hints;
 	const gchar *service_name;
@@ -326,6 +373,10 @@ sasl_gssapi_challenge_sync (CamelSasl *sasl,
 		if (ai == NULL)
 			goto exit;
 
+		/* HTTP authentication should be SPNEGO not just KRB5 */
+		if (!strcmp (service_name, "HTTP"))
+			priv->mech = (gss_OID)&gss_mech_spnego;
+
 		str = g_strdup_printf ("%s@%s", service_name, ai->ai_canonname);
 		camel_freeaddrinfo (ai);
 
@@ -335,7 +386,7 @@ sasl_gssapi_challenge_sync (CamelSasl *sasl,
 		g_free (str);
 
 		if (major != GSS_S_COMPLETE) {
-			gssapi_set_exception (major, minor, error);
+			gssapi_set_exception (priv->mech, major, minor, error);
 			goto exit;
 		}
 
@@ -360,12 +411,12 @@ sasl_gssapi_challenge_sync (CamelSasl *sasl,
 		major = gss_init_sec_context (
 			&minor, GSS_C_NO_CREDENTIAL,
 			&priv->ctx, priv->target,
-			GSS_C_OID_KRBV5_DES,
+			priv->mech,
 			GSS_C_MUTUAL_FLAG |
 			GSS_C_REPLAY_FLAG |
 			GSS_C_SEQUENCE_FLAG,
 			0, GSS_C_NO_CHANNEL_BINDINGS,
-			input_token, &mech, &outbuf, &flags, &time);
+			input_token, &priv->used_mech, &outbuf, &flags, &time);
 
 		switch (major) {
 		case GSS_S_COMPLETE:
@@ -375,13 +426,14 @@ sasl_gssapi_challenge_sync (CamelSasl *sasl,
 			priv->state = GSSAPI_STATE_CONTINUE_NEEDED;
 			break;
 		default:
-			if (major == (OM_uint32) GSS_S_FAILURE &&
+			if (priv->used_mech == GSS_C_OID_KRBV5_DES &&
+			    major == (OM_uint32) GSS_S_FAILURE &&
 			    (minor == (OM_uint32) KRB5KRB_AP_ERR_TKT_EXPIRED ||
 			     minor == (OM_uint32) KRB5KDC_ERR_NEVER_VALID) &&
 			    send_dbus_message (user))
 					goto challenge;
 
-			gssapi_set_exception (major, minor, error);
+			gssapi_set_exception (priv->used_mech, major, minor, error);
 			goto exit;
 		}
 
@@ -405,7 +457,7 @@ sasl_gssapi_challenge_sync (CamelSasl *sasl,
 
 		major = gss_unwrap (&minor, priv->ctx, &inbuf, &outbuf, &conf_state, &qop);
 		if (major != GSS_S_COMPLETE) {
-			gssapi_set_exception (major, minor, error);
+			gssapi_set_exception (priv->used_mech, major, minor, error);
 			goto exit;
 		}
 
@@ -444,7 +496,7 @@ sasl_gssapi_challenge_sync (CamelSasl *sasl,
 
 		major = gss_wrap (&minor, priv->ctx, FALSE, qop, &inbuf, &conf_state, &outbuf);
 		if (major != GSS_S_COMPLETE) {
-			gssapi_set_exception (major, minor, error);
+			gssapi_set_exception (priv->used_mech, major, minor, error);
 			g_free (str);
 			goto exit;
 		}
@@ -502,6 +554,7 @@ camel_sasl_gssapi_init (CamelSaslGssapi *sasl)
 	sasl->priv->target = GSS_C_NO_NAME;
 	sasl->priv->override_host = NULL;
 	sasl->priv->override_user = NULL;
+	sasl->priv->mech = GSS_C_OID_KRBV5_DES;
 #endif /* HAVE_KRB5 */
 }
 
