@@ -1,17 +1,17 @@
 /*
  * camel-imapx-mailbox.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -46,12 +46,8 @@ struct _CamelIMAPXMailboxPrivate {
 	guint32 uidnext;
 	guint32 uidvalidity;
 	guint64 highestmodseq;
-	guint32 permanentflags;
-
-	CamelIMAPXMailboxState state;
 
 	GMutex property_lock;
-	GRecMutex update_lock;
 
 	/* Protected by the "property_lock". */
 	GHashTable *attributes;
@@ -98,7 +94,6 @@ imapx_mailbox_finalize (GObject *object)
 	g_free (priv->name);
 
 	g_mutex_clear (&priv->property_lock);
-	g_rec_mutex_clear (&priv->update_lock);
 	g_hash_table_destroy (priv->attributes);
 	g_sequence_free (priv->message_map);
 	g_strfreev (priv->quota_roots);
@@ -125,10 +120,7 @@ camel_imapx_mailbox_init (CamelIMAPXMailbox *mailbox)
 	mailbox->priv = CAMEL_IMAPX_MAILBOX_GET_PRIVATE (mailbox);
 
 	g_mutex_init (&mailbox->priv->property_lock);
-	g_rec_mutex_init (&mailbox->priv->update_lock);
 	mailbox->priv->message_map = g_sequence_new (NULL);
-	mailbox->priv->permanentflags = ~0;
-	mailbox->priv->state = CAMEL_IMAPX_MAILBOX_STATE_CREATED;
 }
 
 /**
@@ -220,7 +212,6 @@ camel_imapx_mailbox_clone (CamelIMAPXMailbox *mailbox,
 	clone->priv->uidnext = mailbox->priv->uidnext;
 	clone->priv->uidvalidity = mailbox->priv->uidvalidity;
 	clone->priv->highestmodseq = mailbox->priv->highestmodseq;
-	clone->priv->state = mailbox->priv->state;
 
 	clone->priv->quota_roots = g_strdupv (mailbox->priv->quota_roots);
 
@@ -241,46 +232,6 @@ camel_imapx_mailbox_clone (CamelIMAPXMailbox *mailbox,
 	return clone;
 }
 
-/**
- * camel_imapx_mailbox_get_state:
- * @mailbox: a #CamelIMAPXMailbox
- *
- * Returns current state of the mailbox. This is used for folder
- * structure updates, to identify newly created, updated, renamed
- * or removed mailboxes.
- *
- * Returns: Current (update) state of the mailbox.
- *
- * Since: 3.12.9
- **/
-CamelIMAPXMailboxState
-camel_imapx_mailbox_get_state (CamelIMAPXMailbox *mailbox)
-{
-	g_return_val_if_fail (CAMEL_IS_IMAPX_MAILBOX (mailbox), CAMEL_IMAPX_MAILBOX_STATE_UNKNOWN);
-
-	return mailbox->priv->state;
-}
-
-/**
- * camel_imapx_mailbox_set_state:
- * @mailbox: a #CamelIMAPXMailbox
- * @state: a new #CamelIMAPXMailboxState to set
- *
- * Sets current (update) state of the mailbox. This is used for folder
- * structure updates, to identify newly created, updated, renamed
- * or removed mailboxes.
- *
- * Since: 3.12.9
- **/
-void
-camel_imapx_mailbox_set_state (CamelIMAPXMailbox *mailbox,
-			       CamelIMAPXMailboxState state)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_MAILBOX (mailbox));
-
-	mailbox->priv->state = state;
-}
-
 /**
  * camel_imapx_mailbox_exists:
  * @mailbox: a #CamelIMAPXMailbox
@@ -711,41 +662,6 @@ camel_imapx_mailbox_set_highestmodseq (CamelIMAPXMailbox *mailbox,
 	mailbox->priv->highestmodseq = highestmodseq;
 }
 
-/**
- * camel_imapx_mailbox_get_permanentflags:
- * @mailbox: a #CamelIMAPXMailbox
- *
- * Returns: PERMANENTFLAGS response for the mailbox, or ~0, if the mailbox
- *    was not selected yet.
- *
- * Since: 3.12.8
- **/
-guint32
-camel_imapx_mailbox_get_permanentflags (CamelIMAPXMailbox *mailbox)
-{
-	g_return_val_if_fail (CAMEL_IS_IMAPX_MAILBOX (mailbox), ~0);
-
-	return mailbox->priv->permanentflags;
-}
-
-/**
- * camel_imapx_mailbox_set_permanentflags:
- * @mailbox: a #CamelIMAPXMailbox
- * @permanentflags: a newly-reported "PERMANENTFLAGS" value
- *
- * Updates the last know value for PERMANENTFLAGS for this mailbox.
- *
- * Since: 3.12.8
- **/
-void
-camel_imapx_mailbox_set_permanentflags (CamelIMAPXMailbox *mailbox,
-					guint32 permanentflags)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_MAILBOX (mailbox));
-
-	mailbox->priv->permanentflags = permanentflags;
-}
-
 /**
  * camel_imapx_mailbox_dup_quota_roots:
  * @mailbox: a #CamelIMAPXMailbox
@@ -1192,20 +1108,3 @@ camel_imapx_mailbox_handle_status_response (CamelIMAPXMailbox *mailbox,
 		mailbox->priv->highestmodseq = value64;
 }
 
-/* Prevents running FETCH and STORE at the same time for the given mailbox */
-void
-camel_imapx_mailbox_lock_update (CamelIMAPXMailbox *mailbox)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_MAILBOX (mailbox));
-
-	g_rec_mutex_lock (&mailbox->priv->update_lock);
-}
-
-/* Prevents running FETCH and STORE at the same time for the given mailbox */
-void
-camel_imapx_mailbox_unlock_update (CamelIMAPXMailbox *mailbox)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_MAILBOX (mailbox));
-
-	g_rec_mutex_unlock (&mailbox->priv->update_lock);
-}
