@@ -1,17 +1,17 @@
 /*
  * camel-imapx-mailbox.h
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -120,11 +120,6 @@ guint64		camel_imapx_mailbox_get_highestmodseq
 void		camel_imapx_mailbox_set_highestmodseq
 					(CamelIMAPXMailbox *mailbox,
 					 guint64 highestmodseq);
-guint32		camel_imapx_mailbox_get_permanentflags
-					(CamelIMAPXMailbox *mailbox);
-void		camel_imapx_mailbox_set_permanentflags
-					(CamelIMAPXMailbox *mailbox,
-					 guint32 permanentflags);
 gchar **	camel_imapx_mailbox_dup_quota_roots
 					(CamelIMAPXMailbox *mailbox);
 void		camel_imapx_mailbox_set_quota_roots
