@@ -1,17 +1,17 @@
 /*
  * camel-imapx-settings.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -46,8 +46,6 @@ struct _CamelIMAPXSettingsPrivate {
 	gboolean use_real_trash_path;
 	gboolean use_shell_command;
 	gboolean use_subscriptions;
-	gboolean ignore_other_users_namespace;
-	gboolean ignore_shared_folders_namespace;
 
 	CamelSortType fetch_order;
 };
@@ -77,9 +75,7 @@ enum {
 	PROP_USE_REAL_JUNK_PATH,
 	PROP_USE_REAL_TRASH_PATH,
 	PROP_USE_SHELL_COMMAND,
-	PROP_USE_SUBSCRIPTIONS,
-	PROP_IGNORE_OTHER_USERS_NAMESPACE,
-	PROP_IGNORE_SHARED_FOLDERS_NAMESPACE
+	PROP_USE_SUBSCRIPTIONS
 };
 
 G_DEFINE_TYPE_WITH_CODE (
@@ -239,18 +235,6 @@ imapx_settings_set_property (GObject *object,
 				CAMEL_IMAPX_SETTINGS (object),
 				g_value_get_boolean (value));
 			return;
-
-		case PROP_IGNORE_OTHER_USERS_NAMESPACE:
-			camel_imapx_settings_set_ignore_other_users_namespace (
-				CAMEL_IMAPX_SETTINGS (object),
-				g_value_get_boolean (value));
-			return;
-
-		case PROP_IGNORE_SHARED_FOLDERS_NAMESPACE:
-			camel_imapx_settings_set_ignore_shared_folders_namespace (
-				CAMEL_IMAPX_SETTINGS (object),
-				g_value_get_boolean (value));
-			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -430,20 +414,6 @@ imapx_settings_get_property (GObject *object,
 				camel_imapx_settings_get_use_subscriptions (
 				CAMEL_IMAPX_SETTINGS (object)));
 			return;
-
-		case PROP_IGNORE_OTHER_USERS_NAMESPACE:
-			g_value_set_boolean (
-				value,
-				camel_imapx_settings_get_ignore_other_users_namespace (
-				CAMEL_IMAPX_SETTINGS (object)));
-			return;
-
-		case PROP_IGNORE_SHARED_FOLDERS_NAMESPACE:
-			g_value_set_boolean (
-				value,
-				camel_imapx_settings_get_ignore_shared_folders_namespace (
-				CAMEL_IMAPX_SETTINGS (object)));
-			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -742,30 +712,6 @@ camel_imapx_settings_class_init (CamelIMAPXSettingsClass *class)
 			G_PARAM_READWRITE |
 			G_PARAM_CONSTRUCT |
 			G_PARAM_STATIC_STRINGS));
-
-	g_object_class_install_property (
-		object_class,
-		PROP_IGNORE_OTHER_USERS_NAMESPACE,
-		g_param_spec_boolean (
-			"ignore-other-users-namespace",
-			"Ignore Other Users Namespace",
-			"Whether to ignore other users namespace",
-			FALSE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT |
-			G_PARAM_STATIC_STRINGS));
-
-	g_object_class_install_property (
-		object_class,
-		PROP_IGNORE_SHARED_FOLDERS_NAMESPACE,
-		g_param_spec_boolean (
-			"ignore-shared-folders-namespace",
-			"Ignore Shared Folders Namespace",
-			"Whether to ignore shared folders namespace",
-			FALSE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT |
-			G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -1555,88 +1501,6 @@ camel_imapx_settings_set_use_namespace (CamelIMAPXSettings *settings,
 	g_object_notify (G_OBJECT (settings), "use-namespace");
 }
 
-/**
- * camel_imapx_settings_get_ignore_other_users_namespace:
- * @settings: a #CamelIMAPXSettings
- *
- * Returns whether to ignore namespace for other users.
- *
- * Returns: whether to ignore namespace for other users
- *
- * Since: 3.12.9
- **/
-gboolean
-camel_imapx_settings_get_ignore_other_users_namespace (CamelIMAPXSettings *settings)
-{
-	g_return_val_if_fail (CAMEL_IS_IMAPX_SETTINGS (settings), FALSE);
-
-	return settings->priv->ignore_other_users_namespace;
-}
-
-/**
- * camel_imapx_settings_set_ignore_other_users_namespace:
- * @settings: a #CamelIMAPXSettings
- * @ignore: whether to ignore the namespace
- *
- * Sets whether to ignore other users namespace.
- *
- * Since: 3.12.9
- **/
-void
-camel_imapx_settings_set_ignore_other_users_namespace (CamelIMAPXSettings *settings,
-						       gboolean ignore)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_SETTINGS (settings));
-
-	if (settings->priv->ignore_other_users_namespace == ignore)
-		return;
-
-	settings->priv->ignore_other_users_namespace = ignore;
-
-	g_object_notify (G_OBJECT (settings), "ignore-other-users-namespace");
-}
-
-/**
- * camel_imapx_settings_get_ignore_shared_folders_namespace:
- * @settings: a #CamelIMAPXSettings
- *
- * Returns whether to ignore namespace for shared folders.
- *
- * Returns: whether to ignore namespace for shared folders
- *
- * Since: 3.12.9
- **/
-gboolean
-camel_imapx_settings_get_ignore_shared_folders_namespace (CamelIMAPXSettings *settings)
-{
-	g_return_val_if_fail (CAMEL_IS_IMAPX_SETTINGS (settings), FALSE);
-
-	return settings->priv->ignore_shared_folders_namespace;
-}
-
-/**
- * camel_imapx_settings_set_ignore_shared_folders_namespace:
- * @settings: a #CamelIMAPXSettings
- * @ignore: whether to ignore the namespace
- *
- * Sets whether to ignore shared folders namespace.
- *
- * Since: 3.12.9
- **/
-void
-camel_imapx_settings_set_ignore_shared_folders_namespace (CamelIMAPXSettings *settings,
-							  gboolean ignore)
-{
-	g_return_if_fail (CAMEL_IS_IMAPX_SETTINGS (settings));
-
-	if (settings->priv->ignore_shared_folders_namespace == ignore)
-		return;
-
-	settings->priv->ignore_shared_folders_namespace = ignore;
-
-	g_object_notify (G_OBJECT (settings), "ignore-shared-folders-namespace");
-}
-
 /**
  * camel_imapx_settings_get_use_qresync:
  * @settings: a #CamelIMAPXSettings
