@@ -1,17 +1,17 @@
 /*
  * camel-imapx-settings.h
  *
- * This library is free software you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -133,16 +133,6 @@ gboolean	camel_imapx_settings_get_use_namespace
 void		camel_imapx_settings_set_use_namespace
 						(CamelIMAPXSettings *settings,
 						 gboolean use_namespace);
-gboolean	camel_imapx_settings_get_ignore_other_users_namespace
-						(CamelIMAPXSettings *settings);
-void		camel_imapx_settings_set_ignore_other_users_namespace
-						(CamelIMAPXSettings *settings,
-						 gboolean ignore);
-gboolean	camel_imapx_settings_get_ignore_shared_folders_namespace
-						(CamelIMAPXSettings *settings);
-void		camel_imapx_settings_set_ignore_shared_folders_namespace
-						(CamelIMAPXSettings *settings,
-						 gboolean ignore);
 gboolean	camel_imapx_settings_get_use_qresync
 						(CamelIMAPXSettings *settings);
 void		camel_imapx_settings_set_use_qresync
