@@ -2,17 +2,18 @@
 /*
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This library is free software; you can redistribute it and/or modify it
+ * This library is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
  * This library is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 #ifndef CAMEL_IMAPX_UTILS_H
@@ -153,7 +154,7 @@ void		imapx_set_message_info_flags_for_new_message
 						 CamelFlag *server_user_flags,
 						 gboolean force_user_flags,
 						 CamelTag *user_tags,
-						 guint32 permanent_flags);
+						 CamelFolder *folder);
 void		imapx_update_store_summary	(CamelFolder *folder);
 
 gchar *		camel_imapx_dup_uid_from_summary_index
@@ -281,6 +282,7 @@ struct _status_info {
 			gchar *oldname;
 			gchar *newname;
 		} newname;
+		guint32 permanentflags;
 		struct {
 			guint64 uidvalidity;
 			guint32 uid;
