@@ -163,6 +163,9 @@ local_folder_constructed (GObject *object)
 	gchar *root_path;
 	gchar *path;
 
+	/* Chain up to parent's method. */
+	G_OBJECT_CLASS (camel_local_folder_parent_class)->constructed (object);
+
 	folder = CAMEL_FOLDER (object);
 	full_name = camel_folder_get_full_name (folder);
 	parent_store = camel_folder_get_parent_store (folder);
