@@ -915,7 +915,7 @@ gnome_online_accounts_account_added_cb (EGoaClient *goa_client,
 
 	if (source_uid == NULL && backend_name != NULL)
 		backend_factory = e_data_factory_ref_backend_factory (
-			E_DATA_FACTORY (server), backend_name);
+			E_DATA_FACTORY (server), backend_name, E_SOURCE_EXTENSION_COLLECTION);
 
 	if (backend_factory != NULL) {
 		gnome_online_accounts_create_collection (
@@ -1235,8 +1235,7 @@ gnome_online_accounts_constructed (GObject *object)
 		extension);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_gnome_online_accounts_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_gnome_online_accounts_parent_class)->constructed (object);
 }
 
 static gboolean
@@ -1283,6 +1282,9 @@ gnome_online_accounts_get_access_token_sync (EOAuth2Support *support,
 	g_object_unref (goa_account);
 	g_object_unref (goa_object);
 
+	if (error && *error)
+		g_dbus_error_strip_remote_error (*error);
+
 	g_prefix_error (
 		error,
 		_("Failed to obtain an access token for '%s': "),
