@@ -707,7 +707,7 @@ ubuntu_online_accounts_account_created_cb (AgManager *ag_manager,
 
 	if (source_uid == NULL && backend_name != NULL)
 		backend_factory = e_data_factory_ref_backend_factory (
-			E_DATA_FACTORY (server), backend_name);
+			E_DATA_FACTORY (server), backend_name, E_SOURCE_EXTENSION_COLLECTION);
 
 	if (backend_factory != NULL) {
 		ubuntu_online_accounts_collect_userinfo (
@@ -899,8 +899,7 @@ ubuntu_online_accounts_constructed (GObject *object)
 		extension);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_ubuntu_online_accounts_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_ubuntu_online_accounts_parent_class)->constructed (object);
 }
 
 static gboolean
