@@ -1,17 +1,17 @@
 /*
  * evolution-source-registry.c
  *
- * This library is free software you can redistribute it and/or modify it
+ * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.
  *
- * This library is distributed in the hope that it will be useful, but
+ * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
  * for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -216,7 +216,7 @@ reload:
 		const gchar *config_dir;
 		gchar *dirname;
 
-		e_source_registry_debug_print ("Reloading...\n");
+		g_print ("Reloading...\n");
 
 		/* It's possible the Reload is called after restore, where
 		 * the ~/.config/evolution/sources directory can be missing,
